==> web-fw2_2_2.zip: web-fw2_2_2/j2src/weber/org/itscool/commons/request/HttpGeneralForm.java <==
package org.itscool.commons.request;

import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.io.EOFException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

import javax.servlet.http.HttpServletRequest;

import org.itscool.commons.util.URLDecodeUtil;


/**
 * ۃNGXgp[^ێNX
 * @version 1.00A yyyy/mm/dd VK쐬
 * @version 1.00B 2006/03/08 POST\bhȊOŏdp[^݂ꍇA
 * ŏɑIꂽڂێȂۂւ̑ΉǉB
 */
public abstract class HttpGeneralForm extends GeneralForm{
    /** dL[Xg */
	private HashMap duplicateKeys = new HashMap();
	
    /**
     * HttpServletRequestCX^X̎M
     * @param req HttpServletRequestCX^X
     * @throws IOException
     */
    public void parseData(HttpServletRequest req, String encode) throws IOException {
    	//System.out.println("MMMEEEETTTTHHHHOOOODDD:"+req.getMethod());
    	
    	ByteArrayOutputStream bao = new ByteArrayOutputStream();
        DataInputStream dis = new DataInputStream(req.getInputStream());
        
        boolean flag=true;
        while(flag) {
            try {
                byte b=dis.readByte();
                bao.write(b);
            } catch(EOFException e){
                flag=false;
            }
        }
        //formANVɂmethodw肳ĂȂꍇInputStream擾
        //łȂۂ̑Ή
        if( bao.size() == 0 ){
            doDefaultParseData(req, encode);
        }else{
        	doParseData(bao.toByteArray(), encode);
        }
    }
    

    
    
//    public void parseData(HttpServletRequest req) throws IOException {
//        ByteArrayOutputStream bao = new ByteArrayOutputStream();
//        InputStreamReader isr = new InputStreamReader(req.getInputStream(), "JISAutoDetect");
//        BufferedReader br = new BufferedReader(isr);
//        
//        boolean flag=true;
//        StringBuffer sb = new StringBuffer();
//        while(flag) {
//            try {
//                String str = br.readLine();
//                if(str == null){
//                    flag = false;
//                    break;
//                }
//                sb.append( str );
//               
//            } catch(EOFException e){
//                flag=false;
//            }
//        }
//        
//        //formANVɂmethodw肳ĂȂꍇInputStream擾
//        //łȂۂ̑Ή
//        if( sb.length() == 0 || sb.toString().length() == 0 ){
//            doDefaultParseData(req);
//        }else{
//            doParseData(sb.toString().getBytes("ISO-8859-1"));
//            System.out.println(new String( sb.toString().getBytes(),  "JIS" ));
//        }
//    }
//    
    /**
     * NGXgp[^͂܂
     * @param buffer HttpServletRequestCX^XInputStream
     * 擾oCgf[^
     * @param encode GR[fBO
     */
    protected abstract void doParseData(byte[] buffer, String encode );
    
    /**
     * NGXgp[^擾܂
     * @param req HttpServletRequestCX^X
     */
    public void doDefaultParseData(HttpServletRequest req, String encode)
    throws IOException{
//modify 2006/3/8 kano start
//        Enumeration params = req.getParameterNames();
//        while( params.hasMoreElements() ){
//            String name = (String)params.nextElement();
//            String value = req.getParameter(name);
//            try{
//            	value = URLDecodeUtil.decode(value, encode);
//            }catch(Exception e){
//            	throw new IOException(e.getMessage());
//            }
////            //ǑɁu.xvu.yvĂ܂ۂւ̑Ή
////            int index = name.indexOf(".");
////            if(index != -1){
////                name = name.substring(0, index);
////            }
//            this.addParameter(name, value);
//        }
        Map pmap = req.getParameterMap();
		Set hset = pmap.keySet();		
		Iterator iter = hset.iterator();		
		int hno = hset.size();
		while (iter.hasNext()) {
			String name = (String)iter.next();
			String[] values = (String[])pmap.get(name);
			String value;
			if( values.length==1){
				try{
					value = values[0];
	            	value = URLDecodeUtil.decode(value, encode);
	            }catch(Exception e){
	            	throw new IOException(e.getMessage());
	            }
				this.addParameter(name, value);
			}else{
				for(int i=0; i<values.length; i++){
					value = values[i];
					this.addParameter(name, value);
				}
			}
			
		}
		//dL[ɂ镡p[^̃}[Ws
        margeParamsByDuplicateKey();
//modify 2006/3/8 kano end
    }
    /**
     * p[^ǉ܂
     * @param key p[^肷_
     * @param obj Zbgp[^
     */
    public void addParameter(String key, Object obj){
//modify 2006/3/8 kano start
//    	ǑɁu.xvu.yvĂ܂ۂւ̑Ή
        int index = key.indexOf(".");
        if(index != -1){
        	key = key.substring(0, index);
        }
    	Object chkObj = this.getParameter(key);
    	if( chkObj != null){
    		//ɏdp[^o^ĂȂ`FbN
    		ArrayList duplicateParams = (ArrayList)duplicateKeys.get(key);
    		//VKo^
    		if(duplicateParams == null){
    			duplicateParams = new ArrayList();
    			duplicateKeys.put(key, duplicateParams);
    			
    			//ŏ̃p[^Xgɒǉ
    			duplicateParams.add(chkObj);
    		}
    		//dp[^XgZbg
    		duplicateParams.add(obj);
    	}
//    	//ǑɁu.xvu.yvĂ܂ۂւ̑Ή
//        int index = key.indexOf(".");
//        if(index != -1){
//        	key = key.substring(0, index);
//        }else{
//	    	Object chkObj = this.getParameter(key);
//	    	if( chkObj != null){
//	    		//ɏdp[^o^ĂȂ`FbN
//	    		ArrayList duplicateParams = (ArrayList)duplicateKeys.get(key);
//	    		//VKo^
//	    		if(duplicateParams == null){
//	    			duplicateParams = new ArrayList();
//	    			duplicateKeys.put(key, duplicateParams);
//	    			
//	    			//ŏ̃p[^Xgɒǉ
//	    			duplicateParams.add(chkObj);
//	    		}
//	    		//dp[^XgZbg
//	    		duplicateParams.add(obj);
//	    	}
//        }
//modify 2006/3/8 kano end
        super.addParameter(key, obj);
    }
    
    /**
     * `FbN{bNXΉ<BR>
     * dL[ɂ镡p[^ListC^[tF[XɃ}[W܂
     */
    protected void margeParamsByDuplicateKey(){
    	Set keySet = duplicateKeys.keySet();
        Iterator it = keySet.iterator();
        
        while(it.hasNext()){
        	String paramName = (String)it.next();
        	List paramList = (List)duplicateKeys.get(paramName);
        	
        	//o^ς݂̒Pf[^폜
        	super.removeParameter(paramName);
        	//p[^Xgɒu
        	super.addParameter(paramName, paramList);
        }
    }
    
    
//    /**
//     * p[^ǉ܂
//     * @param key p[^肷_
//     * @param obj Zbgp[^
//     */
//    public void addParameter(String key, Object obj){
//        this.put(key, obj);
//    }
    
    
}

==> web-fw3_0_2.zip: web-fw3_0_2/j2src/weber/org/itscool/commons/request/HttpGeneralForm.java <==
package org.itscool.commons.request;

import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.io.EOFException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

import javax.servlet.http.HttpServletRequest;

import org.itscool.commons.bean.BeanFactory;
import org.itscool.commons.logging.AbstractLog;
import org.itscool.commons.logging.SimpleLog;
import org.itscool.commons.util.URLDecodeUtil;


/**
 * ۃNGXgp[^ێNX
 * @version 1.00A yyyy/mm/dd VK쐬
 * @version 1.00B 2006/03/08 POST\bhȊOŏdp[^݂ꍇA
 * ŏɑIꂽڂێȂۂւ̑ΉǉB
 */
public abstract class HttpGeneralForm extends GeneralForm{
    /** dL[Xg */
	private HashMap duplicateKeys = new HashMap();
	protected static AbstractLog log;
	
	static{
		BeanFactory factory = BeanFactory.getInstance();
		try{
			log = (AbstractLog)factory.getInstance("Log");
        	if(!log.isInit()){
        		log = (AbstractLog)factory.createInstance("Log");
        	}
        }catch(Exception ioe){
        	log = SimpleLog.getInstance();
        	log.info(ioe.getMessage());
        }
	}
	
    /**
     * HttpServletRequestCX^X̎M
     * @param req HttpServletRequestCX^X
     * @throws IOException
     */
    public void parseData(HttpServletRequest req, String encode) throws IOException {
    	//System.out.println("MMMEEEETTTTHHHHOOOODDD:"+req.getMethod());
    	
    	ByteArrayOutputStream bao = new ByteArrayOutputStream();
        DataInputStream dis = new DataInputStream(req.getInputStream());
        
        boolean flag=true;
        while(flag) {
            try {
                byte b=dis.readByte();
                bao.write(b);
            } catch(EOFException e){
                flag=false;
            }
        }
        //formANVɂmethodw肳ĂȂꍇInputStream擾
        //łȂۂ̑Ή
        if( bao.size() == 0 ){
            doDefaultParseData(req, encode);
        }else{
        	doParseData(bao.toByteArray(), encode);
        }
    }
    

    
    
//    public void parseData(HttpServletRequest req) throws IOException {
//        ByteArrayOutputStream bao = new ByteArrayOutputStream();
//        InputStreamReader isr = new InputStreamReader(req.getInputStream(), "JISAutoDetect");
//        BufferedReader br = new BufferedReader(isr);
//        
//        boolean flag=true;
//        StringBuffer sb = new StringBuffer();
//        while(flag) {
//            try {
//                String str = br.readLine();
//                if(str == null){
//                    flag = false;
//                    break;
//                }
//                sb.append( str );
//               
//            } catch(EOFException e){
//                flag=false;
//            }
//        }
//        
//        //formANVɂmethodw肳ĂȂꍇInputStream擾
//        //łȂۂ̑Ή
//        if( sb.length() == 0 || sb.toString().length() == 0 ){
//            doDefaultParseData(req);
//        }else{
//            doParseData(sb.toString().getBytes("ISO-8859-1"));
//            System.out.println(new String( sb.toString().getBytes(),  "JIS" ));
//        }
//    }
//    
    /**
     * NGXgp[^͂܂
     * @param buffer HttpServletRequestCX^XInputStream
     * 擾oCgf[^
     * @param encode GR[fBO
     */
    protected abstract void doParseData(byte[] buffer, String encode );
    
    /**
     * NGXgp[^擾܂
     * @param req HttpServletRequestCX^X
     */
    public void doDefaultParseData(HttpServletRequest req, String encode)
    throws IOException{
//modify 2006/3/8 kano start
//        Enumeration params = req.getParameterNames();
//        while( params.hasMoreElements() ){
//            String name = (String)params.nextElement();
//            String value = req.getParameter(name);
//            try{
//            	value = URLDecodeUtil.decode(value, encode);
//            }catch(Exception e){
//            	throw new IOException(e.getMessage());
//            }
////            //ǑɁu.xvu.yvĂ܂ۂւ̑Ή
////            int index = name.indexOf(".");
////            if(index != -1){
////                name = name.substring(0, index);
////            }
//            this.addParameter(name, value);
//        }
    	Map pmap = req.getParameterMap();
		Set hset = pmap.keySet();		
		Iterator iter = hset.iterator();		
		int hno = hset.size();
		while (iter.hasNext()) {
			String name = (String)iter.next();
			String[] values = (String[])pmap.get(name);
			String value;
			String cValue;
			if( values.length==1){
				try{
					value = values[0];
//add 2006/10/06 kano start
			    	//NXXNveBOΉ
					cValue = URLDecodeUtil.filter(value.toString());
					if(!cValue.equals(value)){
						log.warn("recieved cross scripting => "+value);
					}
//add 2006/10/06 kano end
					//GR[fBO
					cValue = URLDecodeUtil.decode(cValue, encode);
	            	
	            }catch(Exception e){
	            	throw new IOException(e.getMessage());
	            }
	            log.debug("request param defaultParse key="+name+" value="+cValue);
				this.addParameter(name, cValue);
			}else{
				for(int i=0; i<values.length; i++){
					value = values[i];
//add 2006/10/06 kano start
			    	//NXXNveBOΉ
					cValue = URLDecodeUtil.filter(value.toString());
					if(!cValue.equals(value)){
						log.warn("recieved cross scripting => "+value);
					}
					//GR[fBO
					cValue = URLDecodeUtil.decode(cValue, encode);
//add 2006/10/06 kano end
					log.debug("request param defaultParse key="+name+" value="+cValue);
					this.addParameter(name, cValue);
				}
			}
			
		}
		//dL[ɂ镡p[^̃}[Ws
        margeParamsByDuplicateKey();
//modify 2006/3/8 kano end
    }
    /**
     * p[^ǉ܂
     * @param key p[^肷_
     * @param obj Zbgp[^
     */
    public void addParameter(String key, Object obj){
//modify 2006/3/8 kano start
//    	ǑɁu.xvu.yvĂ܂ۂւ̑Ή
        int index = key.indexOf(".");
        if(index != -1){
        	key = key.substring(0, index);
        }
    	Object chkObj = this.getParameter(key);
    	
//add 2006/10/06 kano start
    	if( obj instanceof java.lang.String){
    	//NXXNveBOΉ
    		obj = URLDecodeUtil.filter(obj.toString());
    	}
//add 2006/10/06 kano end
    	
    	if( chkObj != null){
    		//ɏdp[^o^ĂȂ`FbN
    		ArrayList duplicateParams = (ArrayList)duplicateKeys.get(key);
    		//VKo^
    		if(duplicateParams == null){
    			duplicateParams = new ArrayList();
    			duplicateKeys.put(key, duplicateParams);
    			
    			//ŏ̃p[^Xgɒǉ
    			duplicateParams.add(chkObj);
    		}
    		//dp[^XgZbg
    		duplicateParams.add(obj);
    	}
//    	//ǑɁu.xvu.yvĂ܂ۂւ̑Ή
//        int index = key.indexOf(".");
//        if(index != -1){
//        	key = key.substring(0, index);
//        }else{
//	    	Object chkObj = this.getParameter(key);
//	    	if( chkObj != null){
//	    		//ɏdp[^o^ĂȂ`FbN
//	    		ArrayList duplicateParams = (ArrayList)duplicateKeys.get(key);
//	    		//VKo^
//	    		if(duplicateParams == null){
//	    			duplicateParams = new ArrayList();
//	    			duplicateKeys.put(key, duplicateParams);
//	    			
//	    			//ŏ̃p[^Xgɒǉ
//	    			duplicateParams.add(chkObj);
//	    		}
//	    		//dp[^XgZbg
//	    		duplicateParams.add(obj);
//	    	}
//        }
//modify 2006/3/8 kano end
        super.addParameter(key, obj);
    }
    
    /**
     * `FbN{bNXΉ<BR>
     * dL[ɂ镡p[^ListC^[tF[XɃ}[W܂
     */
    protected void margeParamsByDuplicateKey(){
    	Set keySet = duplicateKeys.keySet();
        Iterator it = keySet.iterator();
        
        while(it.hasNext()){
        	String paramName = (String)it.next();
        	List paramList = (List)duplicateKeys.get(paramName);
        	
        	//o^ς݂̒Pf[^폜
        	super.removeParameter(paramName);
        	//p[^Xgɒu
        	super.addParameter(paramName, paramList);
        }
    }
    
    
//    /**
//     * p[^ǉ܂
//     * @param key p[^肷_
//     * @param obj Zbgp[^
//     */
//    public void addParameter(String key, Object obj){
//        this.put(key, obj);
//    }
    
    
}
